<?php

namespace Drupal\lingotek_overrides\Plugin\lingotek_overrides\FormField;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityPublishedInterface;
use Drupal\lingotek_overrides\Plugin\lingotek_overrides\FormFieldBase;

/**
 * Defines a Lingotek form-field plugin for an entity's changed date.
 *
 * @LingotekOverridesFormField(
 *   id = "lingotek_overrides_status",
 *   title = @Translation("Status"),
 *   weight = 950,
 *   form_ids = {
 *     "lingotek_management",
 *     "lingotek_entity_management",
 *   }
 * )
 */
class Status extends FormFieldBase {

  /**
   * {@inheritdoc}
   */
  public function getHeader($entity_type_id = NULL) {
    return $this->weight($this->getPluginDefinition()['title']);
  }

  /**
   * {@inheritdoc}
   */
  public function getData(EntityInterface $entity) {
    $statuses = [];

    if ($entity instanceof EntityPublishedInterface) {
      /** @var \Drupal\Core\Entity\EntityPublishedInterface|\Drupal\Core\Entity\TranslatableInterface $entity */
      $languages = array_keys($entity->getTranslationLanguages());

      foreach ($languages as $language) {
        $translation = $entity->getTranslation($language);
        $statuses[$translation->isPublished()][] = $language;
      }
      $status = $entity->isPublished() ? $this->t('Published') : $this->t('Unpublished');
    }

    if ($statuses) {
      $list['#theme'] = 'item_list';

      foreach ($statuses as $status => $langcodes) {
        $parameters = ['%langcodes' => implode(', ', $langcodes)];
        $list['#items'][] = $status ? $this->t('Published: %langcodes', $parameters) : $this->t('Unpublished: %langcodes', $parameters);
      }
    }

    return $this->weight($list ?? '');
  }

}
